/* @(#)root/html:$Id: LinkDef.h 26828 2008-12-11 11:24:38Z axel $ */

/*************************************************************************
 * Copyright (C) 1995-2000, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;
#pragma link C++ nestedclasses;

#pragma link C++ global gHtml;

#pragma link C++ class THtml;
#pragma link C++ class TDocParser;
#pragma link C++ class TDocOutput;
#pragma link C++ class TDocDirective;
#pragma link C++ class TDocHtmlDirective;
#pragma link C++ class TDocMacroDirective;
#pragma link C++ class TDocLatexDirective;
#pragma link C++ class TClassDocOutput;
#pragma link C++ class TClassDocInfo;
#pragma link C++ class TModuleDocInfo;
#pragma link C++ class TLibraryDocInfo;
#pragma link C++ class THtml::THelperBase;
#pragma link C++ class THtml::TModuleDefinition;
#pragma link C++ class THtml::TFileDefinition;
#pragma link C++ class THtml::TPathDefinition;
#pragma link C++ class THtml::TFileSysEntry;
#pragma link C++ class THtml::TFileSysDir;
#pragma link C++ class THtml::TFileSysRoot;
#pragma link C++ class THtml::TFileSysDB;
#endif
